/******************************************************************
Copyright (c) 1996 Novell, Inc. All Rights Reserved.

THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND
TREATIES. USE AND REDISTRIBUTION OF THIS WORK IS SUBJECT TO THE
LICENSE AGREEMENT ACCOMPANYING THE SOFTWARE DEVELOPMENT KIT (SDK)
THAT CONTAINS THIS WORK. PURSUANT TO THE SDK LICENSE AGREEMENT,
NOVELL HEREBY GRANTS TO DEVELOPER A ROYALTY-FREE, NON-EXCLUSIVE
LICENSE TO INCLUDE NOVELL'S SAMPLE CODE IN ITS PRODUCT. NOVELL
GRANTS DEVELOPER WORLDWIDE DISTRIBUTION RIGHTS TO MARKET,
DISTRIBUTE, OR SELL NOVELL'S SAMPLE CODE AS A COMPONENT OF
DEVELOPER'S PRODUCTS. NOVELL SHALL HAVE NO OBLIGATIONS TO
DEVELOPER OR DEVELOPER'S CUSTOMERS WITH RESPECT TO THIS CODE.
******************************************************************/

package com.novell.nds.dirxml.driver.jdbc.db;


/**
 *  Sybase JDBC library.
 *  <p>
 *  Library of functions/procedures for Sybase ASE that supports
 *  the shipping IDM JDBC driver preconfigurations.
 */
abstract public
class Sybase
{

    private static final char DEFAULT_PAD_CHAR = '8';
    private static final int MIN_SIZE = 6;


    //prevents javadoc of default constructor
    private
    Sybase() {}


    /**
     *  Ensures a Sybase password is at least 6 characters long.
     *  If <code>password</code> is less than 6 characters long,
     *  it is padded with character <code>padChar</code> until it
     *  is 6 characters long.
     *  <p>
     *  @param password the password to pad; may be <code>null</code>
     *  @param padChar the character to pad with;
     *      if <code>null</code>, <code>""</code>, or length > 1,
     *      '8' is used.
     *  @return a string length 6 or <code>""</code>;
     *      never returns <code>null</code>
     */
    public static
    String
    PadPassword
    (
        String password,
        String padChar
    )
    {
        StringBuffer buffer;
        char p;
        int size;

        if(password == null)
        {
            return Constants.STR_EMPTY;
        }

        size = password.length();
        if(size >= MIN_SIZE)
        {
            //padding is not necessary
            return password;
        }

        if((padChar == null) ||
           Constants.STR_EMPTY.equals(padChar) ||
           (padChar.length() > 1))
        {
            p = DEFAULT_PAD_CHAR;
        }
        else
        {
            p = padChar.charAt(0);
        }

        buffer = new StringBuffer(MIN_SIZE);
        buffer.append(password);
        while(buffer.length() < MIN_SIZE)
        {
            buffer.append(p);
        }

        return buffer.toString();
    }//PadPassword(String, String)

}//class Sybase
