/******************************************************************
Copyright (c) 1996 Novell, Inc. All Rights Reserved.

THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND
TREATIES. USE AND REDISTRIBUTION OF THIS WORK IS SUBJECT TO THE
LICENSE AGREEMENT ACCOMPANYING THE SOFTWARE DEVELOPMENT KIT (SDK)
THAT CONTAINS THIS WORK. PURSUANT TO THE SDK LICENSE AGREEMENT,
NOVELL HEREBY GRANTS TO DEVELOPER A ROYALTY-FREE, NON-EXCLUSIVE
LICENSE TO INCLUDE NOVELL'S SAMPLE CODE IN ITS PRODUCT. NOVELL
GRANTS DEVELOPER WORLDWIDE DISTRIBUTION RIGHTS TO MARKET,
DISTRIBUTE, OR SELL NOVELL'S SAMPLE CODE AS A COMPONENT OF
DEVELOPER'S PRODUCTS. NOVELL SHALL HAVE NO OBLIGATIONS TO
DEVELOPER OR DEVELOPER'S CUSTOMERS WITH RESPECT TO THIS CODE.
******************************************************************/

package com.novell.nds.dirxml.driver.jdbc.db.lock;


import com.novell.nds.dirxml.driver.jdbc.db.DBLib;


/**
 * A database-native SQL statement that locks a database resource.
 */
public
class DBLockStatement
{

    private String _signature;


    /**
     * Instantiates a statement.
     *
     * @param signature should be a legal SQL signature for the
     * target database; MUST not be <code>null</code>,
     * empty string, or white space
     * @see java.sql.PreparedStatement
     * @see java.sql.Statement
     */
    public
    DBLockStatement(String signature)
    {
        if(DBLib.IsNotValue(signature))
        {
            throw new IllegalArgumentException
                ("Invalid signature.");
        }

        _signature = signature;
    }


    /**
     * Returns this statements signature.
     *
     * @return will not return <code>null</code>
     */
    public
    String
    getSignature()
    {
        return _signature;
    }


    /**
     * Returns a <code>String</code> representation of this statement.
     *
     * @return will not return <code>null</code>
     */
    public
    String
    toString()
    {
        return _signature;
    }

}//DBLockStatement
